main {
  background: var(--color-bg-tertiary);
}

article {
  width: calc(100% - 1.5em);
  background: var(--color-bg-primary);
  padding: 0.25em 0.75em;
  display: flex;
  flex-direction: column;
  line-height: 1.6;
  font-size: 16px;
  color: var(--color-fg-primary);
}

@media screen and (max-width: 1023px) {
  main {
    padding: 0;
  }
}

@media screen and (min-width: 1024px) {
  article {
    max-width: 50em;
    box-shadow: 0 1px 4px 3px var(--color-shadow);
  }
}

article .p-name {
  color: var(--color-title-fg);
}

article p,
article ul,
article ol {
  /* font-family: Lora, "Palatino Linotype", "Book Antiqua", "New York", "DejaVu serif", serif; */
  font-family: Verdana, sans-serif;
  text-align: justify;
  overflow-wrap: break-word;
  word-break: break-word;
}

article p > img,
article p > video,
article p > audio {
  max-width: 100%;
  display: block;
  margin: 0 auto;
}

article code, .codehilite {
  font-size: 0.9em;
}

a:hover {
  opacity: 0.7;
}

.description h3 {
  font-weight: normal;
  color: var(--color-fg-secondary);
  margin: -.5em auto .5em auto;
}

.meta {
  font-size: 0.75em;
  color: var(--color-fg-tertiary);
  margin-bottom: 2em;
  display: inline-flex;
  align-items: center;
  gap: 0.25em;
}

.meta .p-author {
  display: inline-flex;
  align-items: center;
  gap: 0.25em;
}

.meta .p-author img.u-photo {
  width: 1.25em;
  height: 1.25em;
  border-radius: 50%;
}

.codehilite {
  padding: 0 .5em;
  overflow: auto;
  border: 1px solid var(--color-border);
}

.main-image-container {
  width: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
}

.main-image-container img {
  width: 80%;
}
